from cmdwordplay import *
import os
旁白(["你醒了", "在一个洞里", "而你被眼前的场景吓了一跳——白色的骷髅头堆成了山", "但是你得赶紧出去"])
选择([
    ["爬上去", ["你发现白骨山的山顶刚好到达洞口", "于是你爬了上去"]],
    ["观察四周", ["你什么也没发现"]]],
    1)
旁白('''
本以为外面的世界会好一些
但外面确是一片荒芜
''')
选择([
    ["向前走", lambda:(旁白(["你向前走去"]), os.system("color 1"))],
    ["向后方走", ["你转头向后方看去"]],
    ["向左走", ["你向左边走去", "走了一会你遇到了一只狮子", "你s了"]],
    ["向右边走", ["你向右边走去"]]
])
